Tutorials
=========

.. toctree::
   :maxdepth: 2

   Poisson, Gamma, and Tweedie with French Motor Third-Party Liability Claims <glm_french_motor_tutorial/glm_french_motor.ipynb>
   High Dimensional Fixed Effects with Rossman Sales <rossman/fixed_effects_rossman.ipynb>
   Regularization with King County Housing Sales <regularization_housing_data/regularization_housing.ipynb>
